@@ -1,32 +1,11 @@
 import logging
 
-from .abstractprotocol import AbstractProtocol
+from .pi30 import pi30
 from .protocol_helpers import crcPI as crc
 
 log = logging.getLogger("pi30max")
 
 QUERY_COMMANDS = {
-    "QPI": {
-        "name": "QPI",
-        "description": "Protocol ID inquiry",
-        "help": " -- queries the device protocol ID. e.g. PI30 for HS series",
-        "type": "QUERY",
-        "response": [
-            ["string", "Protocol ID", ""],
-        ],
-        "test_responses": [
-            b"(PI30\x9a\x0b\r",
-        ],
-    },
-    "QID": {
-        "name": "QID",
-        "description": "Device Serial Number inquiry",
-        "type": "QUERY",
-        "response": [["string", "Serial Number", ""]],
-        "test_responses": [
-            b"(9293333010501\xBB\x07\r",
-        ],
-    },
     "QSID": {
         "name": "QSID",
         "description": "Device Serial Number inquiry",
@@ -37,16 +16,6 @@ QUERY_COMMANDS = {
             b"(1492932105105335005535\x94\x0e\r",
         ],
     },
-    "QVFW": {
-        "name": "QVFW",
-        "description": "Main CPU firmware version inquiry",
-        "type": "QUERY",
-        "response": [["string", "Main CPU firmware version", ""]],
-        "test_responses": [
-            b"(VERFW:00072.70\x53\xA7\r",
-            b"(VERFW:00046.05\xbe\xb6\r",
-        ],
-    },
     "QVFW3": {
         "name": "QVFW3",
         "description": "Remote CPU firmware version inquiry",
@@ -247,10 +216,11 @@ QUERY_COMMANDS = {
         "name": "QPIGS2",
         "description": "General Status Parameters inquiry 2",
         "type": "QUERY",
+        "response_type": "SEQUENTIAL",
         "response": [
             ["float", "PV2 Input Current", "A"],
             ["float", "PV2 Input Voltage", "V"],
-            ["int", "PV2 Charging Power", "W"],
+            ["int", "PV2 Charging Power", "W", "solar"],
         ],
         "test_responses": [
             b"(03.1 327.3 01026 \xc9\x8b\r",
@@ -544,24 +514,6 @@ QUERY_COMMANDS = {
             b"(230.0 50.0 0030 44.0 54.0 56.4 46.0 60 0 0 2 0 0 0 0 0 1 1 1 0 1 0 54.0 0 1 224\xeb\xbc\r",
         ],
     },
-    "QMCHGCR": {
-        "name": "QMCHGCR",
-        "description": "Max Charging Current Options inquiry",
-        "type": "QUERY",
-        "response": [["string", "Max Charging Current", "A"]],
-        "test_responses": [
-            b"(010 020 030 040 050 060 070 080 090 100 110 120\x0c\xcb\r",
-        ],
-    },
-    "QMUCHGCR": {
-        "name": "QMUCHGCR",
-        "description": "Max Utility Charging Current Options inquiry",
-        "type": "QUERY",
-        "response": [["string", "Max Utility Charging Current", "A"]],
-        "test_responses": [
-            b"(002 010 020 030 040 050 060 070 080 090 100 110 120\xca#\r",
-        ],
-    },
     "QOPPT": {
         "name": "QOPPT",
         "description": "Device Output Source Priority Time Order Inquiry",
@@ -893,15 +845,22 @@ QUERY_COMMANDS = {
 }
 
 SETTER_COMMANDS = {}
-COMMANDS = QUERY_COMMANDS
-COMMANDS.update(SETTER_COMMANDS)
+# COMMANDS = QUERY_COMMANDS
+# COMMANDS.update(SETTER_COMMANDS)
+COMMANDS_TO_REMOVE = ["Q1", "QID", "QVFW3"]
 
 
-class pi30max(AbstractProtocol):
+class pi30max(pi30):
+    def __str__(self):
+        return "PI30 protocol handler for LV6048MAX and similar inverters"
+
     def __init__(self, *args, **kwargs) -> None:
         super().__init__()
         self._protocol_id = b"PI30MAX"
-        self.COMMANDS = COMMANDS
+        self.COMMANDS.update(QUERY_COMMANDS)
+        # self.COMMANDS = COMMANDS
+        for item in COMMANDS_TO_REMOVE:
+            self.COMMANDS.pop(item)
         self.STATUS_COMMANDS = ["QPIGS", "QPIGS2"]
         self.SETTINGS_COMMANDS = ["QPIRI", "QFLAG"]
         self.DEFAULT_COMMAND = "QPI"
